@@ -16,6 +16,10 @@ from .test_type import AB_TestType
 from .test import AB_Test
 from .file import AB_File
 
+from .continuous_monitoring_systems import AB_Continous_Monitoring_Systems
+from .continuous_monitoring_monitors import AB_Continous_Monitoring_Monitors
+from .continuous_monitoring_monitor_results import AB_Continous_Monitoring_Monitor_Results
+
 SUBOBJ_LK = {"region_id": {"obj": AB_Region},
              "process_id": {"obj": AB_Process},
              "subprocess_id": {"obj": AB_SubProcess},
@@ -24,7 +28,9 @@ SUBOBJ_LK = {"region_id": {"obj": AB_Region},
              "entity_id": {"obj": AB_Entity},
              "controls_datum_id": {"obj": AB_Controls_Data},
              "test_ids": {"obj": AB_Test},
-             "file_ids": {"obj": AB_File}
+             "file_ids": {"obj": AB_File},
+             "continuous_monitoring_system_id": {"obj": AB_Continous_Monitoring_Systems},
+             "continuous_monitoring_monitor_id": {"obj": AB_Continous_Monitoring_Monitors}
             }
 
 
