@@ -12,11 +12,15 @@ import abobjs
 
 class AB_Continous_Monitoring_Monitor_Results(abobjs.AB_Base):
 
-    _endpoint = "/api/v1/continous_monitoring_monitor_results"
+    _endpoint = "/api/v1/continuous_monitoring_monitor_results"
     _single = ".continuous_monitoring_monitor_results[0]"
     _name = "continuous_monitoring_monitor_results"
 
+    _file_modal = "ContinuousMonitoringMonitorResult"
+    _fileable_type = "ContinuousMonitoringMonitorResult"
+
     _uid_field = None
+    _name_field = None
 
     def __init__(self, id=None, api_info=None, **kwargs):
 
